@@ -9,7 +9,7 @@ setMethod('horizonplot',
           definition=function(x, data=NULL, dirXY=y, xlab='Time', ylab='direction', digits=0, ...){
             idx=getZ(x)
             dirLayer <- xyLayer(x, dirXY=substitute(dirXY))
-            z <- zonal(x, dirLayer, mean, digits=digits)
+            z <- zonal(x, dirLayer, digits=digits)
             nRows <- nrow(z)
             zz <- as.data.frame(t(z[,-1]), row.names='')
             names(zz) <- z[,1]
